@@ -1,4 +1,5 @@
 #!/bin/sh
+
 if [ -e /android/system/boot/android-ramdisk.img ]; then
     mount -n -t tmpfs tmpfs $LXC_ROOTFS_PATH
     INITRD=/android/system/boot/android-ramdisk.img
@@ -21,15 +22,11 @@ rm -Rf /dev/socket
 mkdir -p /dev/socket $LXC_ROOTFS_PATH/socket
 mount -n -o bind,rw /dev/socket $LXC_ROOTFS_PATH/socket
 
-# Make sure adbd is not started automatically
-sed -i 's/setprop persist.sys.usb.config adb$/setprop persist.sys.usb.config ""/' $LXC_ROOTFS_PATH/init.rc
+# run config snippet scripts
+run-parts /var/lib/lxc/android/pre-start.d || true
 
-# Make sure the ubuntu_chroot init service does not get started
-sed -i '/ubuntu_chroot init$/,+2d' $LXC_ROOTFS_PATH/init.rc
 sed -i '/on early-init/a \    mkdir /dev/socket\n\    mount none /socket /dev/socket bind' $LXC_ROOTFS_PATH/init.rc
 
-cp -a /var/lib/lxc/android/overrides/* $LXC_ROOTFS_PATH
-
 if [ "$INITRD" = "/android/system/boot/android-ramdisk.img" ]; then
     sed -i "/mount_all /d" $LXC_ROOTFS_PATH/init.*.rc
     sed -i "/on nonencrypted/d" $LXC_ROOTFS_PATH/init.rc
